@@ -7,25 +7,27 @@ pub mod tpls;
 
 use std::borrow::Cow;
 use std::collections::{HashMap, HashSet};
+use std::net::IpAddr;
 use std::path::{Path, PathBuf};
 use std::sync::{Arc, Mutex, RwLock};
 
-use libs::once_cell::sync::Lazy;
-use libs::rayon::prelude::*;
-use libs::tera::{Context, Tera};
-use libs::walkdir::{DirEntry, WalkDir};
+use log;
+use once_cell::sync::Lazy;
+use rayon::prelude::*;
+use tera::{Context, Tera};
+use walkdir::{DirEntry, WalkDir};
 
-use config::{get_config, Config, IndexFormat};
+use config::{Config, IndexFormat, get_config};
 use content::{Library, Page, Paginator, Section, Taxonomy};
-use errors::{anyhow, bail, Result};
-use libs::relative_path::RelativePathBuf;
+use errors::{Result, anyhow, bail};
+use relative_path::RelativePathBuf;
 use std::time::Instant;
 use templates::{load_tera, render_redirect_template};
 use utils::fs::{
     clean_site_output_folder, copy_directory, copy_file_if_needed, create_directory, create_file,
 };
 use utils::net::{get_available_port, is_external_link};
-use utils::templates::{render_template, ShortcodeDefinition};
+use utils::templates::{ShortcodeDefinition, render_template};
 use utils::types::InsertAnchor;
 
 pub static SITE_CONTENT: Lazy<Arc<RwLock<HashMap<RelativePathBuf, String>>>> =
@@ -38,6 +40,8 @@ pub enum BuildMode {
     Disk,
     /// In memory for the content -> `zola serve`
     Memory,
+    /// Both on the filesystem and in memory
+    Both,
 }
 
 #[derive(Debug)]
@@ -65,6 +69,8 @@ pub struct Site {
     include_drafts: bool,
     build_mode: BuildMode,
     shortcode_definitions: HashMap<String, ShortcodeDefinition>,
+    /// Whether to check external links
+    check_external_links: bool,
 }
 
 impl Site {
@@ -108,16 +114,17 @@ impl Site {
             library: Arc::new(RwLock::new(Library::default())),
             build_mode: BuildMode::Disk,
             shortcode_definitions,
+            check_external_links: true,
         };
 
         Ok(site)
     }
 
     /// Enable some `zola serve` related options
-    pub fn enable_serve_mode(&mut self) {
+    pub fn enable_serve_mode(&mut self, build_mode: BuildMode) {
         SITE_CONTENT.write().unwrap().clear();
         self.config.enable_serve_mode();
-        self.build_mode = BuildMode::Memory;
+        self.build_mode = build_mode;
     }
 
     /// Set the site to load the drafts.
@@ -126,6 +133,11 @@ impl Site {
         self.include_drafts = true;
     }
 
+    /// Set the site checker to skip external links check.
+    pub fn skip_external_links_check(&mut self) {
+        self.check_external_links = false;
+    }
+
     /// The index sections are ALWAYS at those paths
     /// There are one index section for the default language + 1 per language
     fn index_section_paths(&self) -> Vec<(PathBuf, Option<&str>)> {
@@ -139,8 +151,8 @@ impl Site {
     /// We avoid the port the server is going to use as it's not bound yet
     /// when calling this function and we could end up having tried to bind
     /// both http and websocket server to the same port
-    pub fn enable_live_reload(&mut self, port_to_avoid: u16) {
-        self.live_reload = get_available_port(port_to_avoid);
+    pub fn enable_live_reload(&mut self, interface: IpAddr, port_to_avoid: u16) {
+        self.live_reload = get_available_port(interface, port_to_avoid);
     }
 
     /// Only used in `zola serve` to re-use the initial websocket port
@@ -165,6 +177,10 @@ impl Site {
         self.output_path = path.as_ref().to_path_buf();
     }
 
+    pub fn minify(&mut self) {
+        self.config.minify_html = true;
+    }
+
     /// Reads all .md files in the `content` directory and create pages/sections
     /// out of them
     pub fn load(&mut self) -> Result<()> {
@@ -203,14 +219,10 @@ impl Site {
             };
 
             // ignore excluded content
-            match &self.config.ignored_content_globset {
-                Some(gs) => {
-                    if gs.is_match(path) {
-                        continue;
-                    }
-                }
-
-                None => (),
+            if let Some(gs) = &self.config.ignored_content_globset
+                && gs.is_match(path)
+            {
+                continue;
             }
 
             // we process a section when we encounter the dir
@@ -286,7 +298,10 @@ impl Site {
                 };
 
                 if is_invalid {
-                    bail!("We can't have a page called `index.md` in the same folder as an index section in {:?}", page.file.parent);
+                    bail!(
+                        "We can't have a page called `index.md` in the same folder as an index section in {:?}",
+                        page.file.parent
+                    );
                 }
             }
 
@@ -338,13 +353,13 @@ impl Site {
                 messages.join("\n")
             );
             match self.config.link_checker.internal_level {
-                config::LinkCheckerLevel::Warn => console::warn(&msg),
+                config::LinkCheckerLevel::Warn => log::warn!("{msg}"),
                 config::LinkCheckerLevel::Error => return Err(anyhow!(msg)),
             }
         }
 
         // check external links, log the results, and error out if needed
-        if self.config.is_in_check_mode() {
+        if self.config.is_in_check_mode() && self.check_external_links {
             let external_link_messages = link_checking::check_external_links(self);
             if !external_link_messages.is_empty() {
                 let messages: Vec<String> = external_link_messages
@@ -358,7 +373,7 @@ impl Site {
                     messages.join("\n")
                 );
                 match self.config.link_checker.external_level {
-                    config::LinkCheckerLevel::Warn => console::warn(&msg),
+                    config::LinkCheckerLevel::Warn => log::warn!("{msg}"),
                     config::LinkCheckerLevel::Error => return Err(anyhow!(msg)),
                 }
             }
@@ -371,14 +386,15 @@ impl Site {
     /// a _index.md to render the index page at the root of the site
     pub fn create_default_index_sections(&mut self) -> Result<()> {
         for (index_path, lang) in self.index_section_paths() {
-            if let Some(index_section) = self.library.read().unwrap().sections.get(&index_path) {
-                if self.config.build_search_index && !index_section.meta.in_search_index {
-                    bail!(
+            if let Some(index_section) = self.library.read().unwrap().sections.get(&index_path)
+                && self.config.build_search_index
+                && !index_section.meta.in_search_index
+            {
+                bail!(
                     "You have enabled search in the config but disabled it in the index section: \
                     either turn off the search in the config or remove `in_search_index = true` from the \
                     section front-matter."
-                    )
-                }
+                )
             }
             let mut library = self.library.write().expect("Get lock for load");
             // Not in else because of borrow checker
@@ -539,7 +555,7 @@ impl Site {
     }
 
     /// Finds the insert_anchor for the parent section of the directory at `path`.
-    /// Defaults to `AnchorInsert::None` if no parent section found
+    /// Defaults to the global setting if no parent section found
     pub fn find_parent_section_insert_anchor(
         &self,
         parent_path: &Path,
@@ -550,10 +566,13 @@ impl Site {
         } else {
             parent_path.join("_index.md")
         };
-        match self.library.read().unwrap().sections.get(&parent) {
-            Some(s) => s.meta.insert_anchor_links,
-            None => InsertAnchor::None,
-        }
+        self.library
+            .read()
+            .unwrap()
+            .sections
+            .get(&parent)
+            .and_then(|s| s.meta.insert_anchor_links)
+            .unwrap_or(self.config.markdown.insert_anchor_links)
     }
 
     /// Find out the direct subsections of each subsection if there are some
@@ -660,16 +679,20 @@ impl Site {
         };
 
         match self.build_mode {
-            BuildMode::Disk => {
+            BuildMode::Disk | BuildMode::Both => {
                 let end_path = current_path.join(filename);
                 create_file(&end_path, &final_content)?;
             }
-            BuildMode::Memory => {
+            _ => (),
+        }
+        match self.build_mode {
+            BuildMode::Memory | BuildMode::Both => {
                 let site_path =
                     if filename != "index.html" { site_path.join(filename) } else { site_path };
 
                 SITE_CONTENT.write().unwrap().insert(site_path, final_content);
             }
+            _ => (),
         }
 
         Ok(current_path)
@@ -789,16 +812,20 @@ impl Site {
     }
 
     pub fn render_themes_css(&self) -> Result<()> {
-        let themes = &self.config.markdown.highlight_themes_css;
-
+        let themes = self
+            .config
+            .markdown
+            .highlighting
+            .as_ref()
+            .map(|x| x.generate_themes_css())
+            .unwrap_or_default();
         if !themes.is_empty() {
             create_directory(&self.static_path)?;
         }
 
-        for t in themes {
-            let p = self.static_path.join(&t.filename);
+        for (filename, content) in themes {
+            let p = self.static_path.join(&filename);
             if !p.exists() {
-                let content = &self.config.markdown.export_theme_css(&t.theme)?;
                 create_file(&p, content)?;
             }
         }
@@ -930,6 +957,10 @@ impl Site {
             components.push(taxonomy.lang.as_ref());
         }
 
+        if let Some(ref taxonomy_root) = self.config.taxonomy_root {
+            components.push(taxonomy_root.as_ref());
+        }
+
         components.push(taxonomy.slug.as_ref());
 
         let list_output =
@@ -965,9 +996,26 @@ impl Site {
 
                 if taxonomy.kind.feed {
                     let tax_path = if taxonomy.lang == self.config.default_language {
-                        PathBuf::from(format!("{}/{}", taxonomy.slug, item.slug))
+                        if let Some(ref taxonomy_root) = self.config.taxonomy_root {
+                            PathBuf::from(format!(
+                                "{}/{}/{}",
+                                taxonomy_root, taxonomy.slug, item.slug
+                            ))
+                        } else {
+                            PathBuf::from(format!("{}/{}", taxonomy.slug, item.slug))
+                        }
                     } else {
-                        PathBuf::from(format!("{}/{}/{}", taxonomy.lang, taxonomy.slug, item.slug))
+                        if let Some(ref taxonomy_root) = self.config.taxonomy_root {
+                            PathBuf::from(format!(
+                                "{}/{}/{}/{}",
+                                taxonomy.lang, taxonomy_root, taxonomy.slug, item.slug
+                            ))
+                        } else {
+                            PathBuf::from(format!(
+                                "{}/{}/{}",
+                                taxonomy.lang, taxonomy.slug, item.slug
+                            ))
+                        }
                     };
                     self.render_feeds(
                         item.pages.iter().map(|p| library.pages.get(p).unwrap()).collect(),
@@ -1116,7 +1164,7 @@ impl Site {
         }
 
         if let Some(ref redirect_to) = section.meta.redirect_to {
-            let permalink: Cow<String> = if is_external_link(redirect_to) {
+            let permalink: Cow<str> = if is_external_link(redirect_to) {
                 Cow::Borrowed(redirect_to)
             } else {
                 Cow::Owned(self.config.make_permalink(redirect_to))
@@ -1208,10 +1256,7 @@ impl Site {
 }
 
 fn log_time(start: Instant, message: &str) -> Instant {
-    let do_print = std::env::var("ZOLA_PERF_LOG").is_ok();
     let now = Instant::now();
-    if do_print {
-        println!("{} took {}ms", message, now.duration_since(start).as_millis());
-    }
+    log::debug!("{} took {}ms", message, now.duration_since(start).as_millis());
     now
 }
